import { ComputedRef, CSSProperties } from 'vue'
import { CommonValue } from '~/common'
import { Query } from '@/api/webApi'

interface TrackNode {
  name: string
  flag: boolean
  labelWidth?: number
  descriptions: string[]
}
interface TrackAirport {
  airport: string
  isDeparture: number
  trackSteps: TrackNode[]
}
interface TrackAirline {
  flightNO: string
  flightDate: string
  airports: TrackAirport[]
}
interface TrackDataContent {
  flightNO: string
  flightDate: string
  airport: string
  isDeparture: number
  dataContent: CommonValue[]
}
interface TrackNodeData {
  C0: CommonValue // 节点名称
  C1: CommonValue // 节点编号
  C2: CommonValue // 总件数
  C3: CommonValue // 时间
}

const simulateTrackNodesMap = {
  departure: [
    {
      name: '收货核单',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '安检',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '理货',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '待运区',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '货站交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '机下交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '装机',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
  ],
  departure2: [
    {
      name: '收货核单',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '安检',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '理货',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '待运区',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '货站交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '机下交接',
      flag: false,
      descriptions: [],
    },
    {
      name: '装机',
      flag: false,
      descriptions: [],
    },
  ],
  arrival: [
    {
      name: '收货核单',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '机下交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '货站交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '提取',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
  ],
  arrival2: [
    {
      name: '收货核单',
      flag: false,
      descriptions: [],
    },
    {
      name: '机下交接',
      flag: false,
      descriptions: [],
    },
    {
      name: '货站交接',
      flag: false,
      descriptions: [],
    },
    {
      name: '提取',
      flag: false,
      descriptions: [],
    },
  ],
  internationalDeparture: [
    {
      name: '入园',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '海关',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '运抵',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '安检',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '收运核单',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '理货',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '拉下',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '待运区',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '货站交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '机下交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '装机',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
  ],
  internationalDeparture2: [
    {
      name: '拉下',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '待运区',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '货站交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '机下交接',
      flag: false,
      descriptions: [],
    },
    {
      name: '装机',
      flag: false,
      descriptions: [],
    },
  ],
  internationalArrival: [
    {
      name: '卸机',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '机下交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '货站交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '理货',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '海关',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '出库',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '退运',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
  ],
  internationalArrival2: [
    {
      name: '卸机',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '机下交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '货站交接',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '理货',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
    {
      name: '运抵',
      flag: true,
      descriptions: ['A32', '534件', '通过', '10:25'],
    },
  ],
}

export default function useTrackData(
  trackName: string,
  trackDataContentList: ComputedRef<TrackDataContent[]>
) {
  const trackAirlines = ref<TrackAirline[]>([])
  const getTrackAirlines = async () => {
    try {
      trackAirlines.value = await trackDataContentList.value.reduce(
        async (
          pre,
          { flightNO, airport, flightDate, isDeparture, dataContent }
        ) => {
          const airlines = await pre
          const trackNodeList = await getTrackData(
            DATACONTENT_ID[
              trackName.endsWith('Waybill') ? 'waybillTrack' : 'goodsTrack'
            ],
            dataContent
          )
          const trackAirport = {
            airport,
            isDeparture,
            trackSteps: trackNodeList.map(({ C0, C1, C2, C3 }) => ({
              name: String(C0 ?? ''),
              flag: Boolean(C1 && C2 && C3),
              descriptions: [
                String(C1 ?? ''),
                String(C2 ?? ''),
                String(C3 ?? ''),
              ],
            })),
          }
          const airline = airlines.find(
            airline =>
              airline.flightNO === flightNO && airline.flightDate === flightDate
          )
          if (airline) {
            airline.airports.push(trackAirport)
          } else {
            airlines.push({
              flightNO,
              flightDate,
              airports: [trackAirport],
            })
          }
          return airlines
        },
        Promise.resolve([] as TrackAirline[])
      )
    } catch (error) {
      console.error(error)
    }
  }
  const getTrackData = async (id: number, dataContent: CommonValue[]) => {
    try {
      const {
        code,
        returnData: { listValues },
        message,
      } = await Query<TrackNodeData>({
        id,
        dataContent,
      })
      if (Number(code) !== 0) {
        throw new Error(message || '失败')
      }
      return listValues
    } catch (error) {
      return Promise.reject(error)
    }
  }

  // watch(trackDataContentList, () => {
  //   getTrackAirlines()
  // })

  const getSimulateTrackData = () => {
    const length = trackName.includes('Waybill') ? 2 : 1
    trackAirlines.value = Array.from({ length }, (_, airlineIndex) => {
      const length = trackName.includes('International') ? 1 : 2
      return {
        flightNO: airlineIndex < 1 ? 'CA1001' : 'CA1003',
        flightDate: '2022/09/10',
        airports: Array.from({ length }, (_, airportIndex) => ({
          airport: airportIndex < 1 ? '深圳机场' : '南京机场',
          isDeparture: trackName.includes('Departure')
            ? airportIndex < 1
              ? 1
              : 0
            : airportIndex < 1
            ? 0
            : 1,
          trackSteps: trackName.includes('International')
            ? trackName.includes('Departure')
              ? airlineIndex < 1
                ? simulateTrackNodesMap.internationalDeparture
                : simulateTrackNodesMap.internationalDeparture2
              : airlineIndex < 1
              ? simulateTrackNodesMap.internationalArrival
              : simulateTrackNodesMap.internationalArrival2
            : trackName.includes('Departure')
            ? airlineIndex < 1
              ? airportIndex < 1
                ? simulateTrackNodesMap.departure
                : simulateTrackNodesMap.arrival
              : airportIndex < 1
              ? simulateTrackNodesMap.departure2
              : simulateTrackNodesMap.arrival2
            : airlineIndex < 1
            ? airportIndex < 1
              ? simulateTrackNodesMap.arrival
              : simulateTrackNodesMap.departure
            : airportIndex < 1
            ? simulateTrackNodesMap.arrival2
            : simulateTrackNodesMap.departure2,
        })),
      }
    })
  }
  onMounted(() => {
    getSimulateTrackData()
  })

  const trackBoxStyle = computed(
    () => (airports: TrackAirport[], index: number) => {
      const style: CSSProperties = {}
      const totalLength = airports.reduce((pre, current) => {
        return pre + current.trackSteps.length - 1
      }, 0)
      style.width = totalLength
        ? `calc((100% - ${airports.length - 1} * 8px) * ${
            (airports[index].trackSteps.length - 1) / totalLength
          })`
        : '100%'
      return style
    }
  )
  return {
    trackAirlines,
    trackBoxStyle,
  }
}
